@@ -3,7 +3,7 @@ package XML::Reader;
 use strict;
 use warnings;
 use Carp;
-use Net::HTTP;
+use Acme::HTTP;
 
 require Exporter;
 
@@ -11,7 +11,7 @@ our @ISA         = qw(Exporter);
 our %EXPORT_TAGS = ( all => [ qw(slurp_xml) ] );
 our @EXPORT_OK   = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT      = qw();
-our $VERSION     = '0.53';
+our $VERSION     = '0.54';
 
 my $use_module;
 
@@ -139,15 +139,9 @@ sub new {
         $fh = $_[0];
     }
     else {
-        if ($_[0] =~ m{\A http:}xms) {
-            my ($host, $get) = $_[0] =~ m{\A http:// ([^/]+) (/ .*) \z}xms ? ($1, $2) :
-              croak "Failed assertion #0041 in XML::Reader->new: Can't parse /http://.../.../ from '$_[0]'";
-
-            $fh = Net::HTTP->new(Host => $host)
-              or croak "Failed assertion #0042 in XML::Reader->new: Can't Net::HTTP->new(Host => '$host') because $@";
-
-            $fh->write_request(GET => $get, 'User-Agent' => 'Mozilla/5.0');
-            $fh->read_response_headers; # this function returns: $code, $msg, %h
+        if ($_[0] =~ m{\A https?:}xms) {
+            $fh = Acme::HTTP->new($_[0])
+              or croak "Failed assertion #0042 in XML::Reader->new: Can't Acme::HTTP->new('$_[0]') because $@";
         }
         else {
             open $fh, '<', $_[0] or croak "Failed assertion #0045 in XML::Reader->new: Can't open < '$_[0]' because $!";
@@ -851,7 +845,7 @@ sub slurp_xml {
 
 package XML::Reader::Token;
 
-our $VERSION = '0.53';
+our $VERSION = '0.54';
 
 sub found_start_tag   { $_[0][0] eq '<'; }
 sub found_end_tag     { $_[0][0] eq '>'; }
